@@ -1,3 +1,3 @@
 from .colorant import colorant
 from .pigment import pigment
-from .projector import projector, to_projector
+from .projector import ProjectorFactory
